@@ -5,6 +5,9 @@ class Config(object):
     def authentication_host(self) -> str:
         raise NotImplementedError(f'authentication_host not implemented in {self.__name__}')
 
+    def git_remote_host(self):
+        raise NotImplementedError(f'git_remote_host not implemented in {self.__name__}')
+
     @classmethod
     def default_config(cls) -> 'Config':
         try:
